@@ -21,7 +21,7 @@ class GenerateFile:
 class _PackagerFiles:
     """ Generates setup, license and gitexclude.
         Only changed non-aesthetic files can trigger a version bump and publish. """
-    extra_aesthetic = "randomtesting.py",
+    extra_aesthetic = "randomtesting.py",  # "licenses"
     extra_non_aesthetic = tuple()
 
     def __init_post__(self):
@@ -101,6 +101,7 @@ class _PackagerFiles:
             "packages": 'find_namespace_packages(exclude=("build*", "dist*"))',
             "extras_require": self.localrepo.extras_require,
             "classifiers": self.get_classifiers(),
+            # "include_package_data": True,
         }
 
         top = CodeLine()
@@ -130,9 +131,10 @@ class _PackagerFiles:
         """ Generate manifest file.
 
             :param generalpackager.Packager self: """
-        return "\n".join(self.localrepo.manifest + [
-            str(self.localrepo.get_metadata_path().relative(self.path)),
-        ])
+        default_manifest = [
+            self.localrepo.get_metadata_path().relative(self.path),
+        ]
+        return "\n".join([f"include {path}" for path in self.localrepo.manifest + default_manifest])
 
     def generate_git_exclude(self):
         """ Generate git exclude file.
