@@ -1,5 +1,5 @@
 
-from generallibrary import Markdown, comma_and_and, current_datetime_formatted
+from generallibrary import Markdown, current_datetime_formatted
 
 
 class _PackagerMarkdown:
@@ -36,7 +36,7 @@ class _PackagerMarkdown:
         for command, packages in options.items():
             row = {"Command": f"`pip install {command}`"}
             for dependency in dependencies_required + dependencies_optional:
-                row[Markdown.link(dependency, url=f"https://pypi.org/project/{dependency}", href=True)] = "Yes" if dependency in packages else "-"
+                row[Markdown.link(dependency, url=f"https://pypi.org/project/{dependency}", href=True)] = "Yes" if dependency in packages else "No"
             list_of_dicts.append(row)
 
         markdown.add_table_lines(*list_of_dicts)
@@ -68,7 +68,7 @@ class _PackagerMarkdown:
         """ :param generalpackager.Packager self:
             :param text:
             :param suffix: """
-        url = f"{self.github.url()}/{suffix}"
+        url = f"{self.github.url}/{suffix}"
         # self.assert_url_up(url=url)  # Wont work for private repos or new files, would have to check after the fact.
         return Markdown.link(text=text, url=url, href=True)
 
@@ -86,34 +86,3 @@ class _PackagerMarkdown:
         line = f"Generated {current_datetime_formatted()} for commit {self.github_link(text=self.commit_sha, suffix=f'commit/{self.commit_sha}')}."
         return Markdown(line).wrap_with_tags("sup")
 
-
-    def generate_readme(self):
-        """ Generate readme markdown and overwrite README.md in local repo.
-
-            :param generalpackager.Packager self: """
-        # Description
-        markdown = Markdown(self.localrepo.description, header=self.name)
-
-        # Badges
-        markdown.add_lines(*self.get_badges_dict().values())
-
-        # Table of contents - Placeholder
-        contents = Markdown(header="Contents", parent=markdown)
-
-        # Installation
-        self.get_installation_markdown().set_parent(parent=markdown)
-
-        # Attributes
-        self.get_attributes_markdown().set_parent(parent=markdown)
-
-        # Todos
-        Markdown(header="Todos", parent=markdown).add_table_lines(*self.localrepo.get_todos())
-
-        # Table of contents - Configuration
-        self.configure_contents_markdown(markdown=contents)
-
-        # Footnote
-        self.get_footnote_markdown().set_parent(parent=markdown)
-
-        # Create actual readme file
-        self.generate_file(self.localrepo.get_readme_path(), markdown)
